/*
 * ================================================================
 *
 * Table definition for mod_benchmark module:
 *
 * ================================================================
 */
IF EXISTS (SELECT * FROM sysobjects WHERE name = 'BENCHMARK_DATE_0' AND type = 'D')
BEGIN
	exec sp_unbindefault "t_benchmark_log.log_date"
	exec sp_unbindefault "t_benchmark_alert.log_date"
	exec sp_unbindefault "t_benchmark_graph.gra_date"

	DROP DEFAULT BENCHMARK_DATE_0
END
IF EXISTS (SELECT * FROM sysobjects WHERE name = 'BENCHMARK_INT_0' AND type = 'D')
BEGIN
	exec sp_unbindefault "t_benchmark_log.log_status"
	exec sp_unbindefault "t_benchmark_log.ben_sec"
	exec sp_unbindefault "t_benchmark_log.ben_usec"
	exec sp_unbindefault "t_benchmark_log.ben_ready"
	exec sp_unbindefault "t_benchmark_log.ben_busy"
	exec sp_unbindefault "t_benchmark_log.ben_pzombie"
	exec sp_unbindefault "t_benchmark_log.ben_prunning"
	exec sp_unbindefault "t_benchmark_log.ben_pstopped"
	exec sp_unbindefault "t_benchmark_log.ben_psleeping"
	exec sp_unbindefault "t_benchmark_log.ben_avgload"
	exec sp_unbindefault "t_benchmark_log.ben_memuse"
	exec sp_unbindefault "t_benchmark_log.ben_swapuse"
	exec sp_unbindefault "t_benchmark_log.ben_cliaddr"
	exec sp_unbindefault "t_benchmark_log.ben_srvaddr"
	exec sp_unbindefault "t_benchmark_log.ben_srvport"
	exec sp_unbindefault "t_benchmark_alert.ben_sec"
	exec sp_unbindefault "t_benchmark_alert.ben_usec"
	exec sp_unbindefault "t_benchmark_alert.ben_cliaddr"
	exec sp_unbindefault "t_benchmark_alert.ben_srvaddr"
	exec sp_unbindefault "t_benchmark_graph.gra_width"
	exec sp_unbindefault "t_benchmark_graph.gra_height"

	DROP DEFAULT BENCHMARK_INT_0
END
IF EXISTS (SELECT * FROM sysobjects WHERE name = 'BENCHMARK_STRING_0' AND type = 'D')
BEGIN
	exec sp_unbindefault "t_benchmark_log.url_value"
	exec sp_unbindefault "t_benchmark_log.arg_value"
	exec sp_unbindefault "t_benchmark_log.fil_value"
	exec sp_unbindefault "t_benchmark_alert.url_value"
	exec sp_unbindefault "t_benchmark_alert.arg_value"
	exec sp_unbindefault "t_benchmark_alert.fil_value"
	exec sp_unbindefault "t_benchmark_graph.gra_name"
	exec sp_unbindefault "t_benchmark_graph.gra_note"
	exec sp_unbindefault "t_benchmark_graph.gra_blob"
	DROP DEFAULT BENCHMARK_STRING_0
END
GO
CREATE DEFAULT BENCHMARK_DATE_0 AS '2002-01-01 00:00:00'
GO
CREATE DEFAULT BENCHMARK_INT_0 AS 0
GO
CREATE DEFAULT BENCHMARK_STRING_0 AS ''
GO

/*
 * ----------------------------------------------------------------
 *
 * t_benchmark_log: contains one row per HTTP request for which
 *		   the module is activated
 * ----------------------------------------------------------------
 */
IF EXISTS (SELECT * FROM sysobjects WHERE name = 't_benchmark_log' AND type = 'U')
	DROP TABLE t_benchmark_log
GO

CREATE TABLE t_benchmark_log (
	log_date 	DATETIME,
	url_value	VARCHAR(250),
	arg_value	VARCHAR(250),
	fil_value	VARCHAR(250),
	log_status	INT,
	ben_sec		INT,
	ben_usec	INT,
	ben_ready	INT,
	ben_busy	INT,
	ben_pzombie	INT,
	ben_prunning	INT,
	ben_pstopped	INT,
	ben_psleeping	INT,
	ben_avgload	INT,
	ben_memuse	INT,
	ben_swapuse	INT,
	ben_cliaddr	INT,
	ben_srvaddr	INT,
	ben_srvport	INT
	)

exec sp_bindefault BENCHMARK_DATE_0, "t_benchmark_log.log_date"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_log.url_value"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_log.arg_value"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_log.fil_value"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.log_status"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_sec"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_usec"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_ready"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_busy"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_pzombie"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_prunning"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_pstopped"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_psleeping"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_avgload"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_memuse"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_swapuse"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_cliaddr"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_srvaddr"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_log.ben_srvport"

/*
 * Notes:
 * =====
 *	Request Stats:
 *	-------------
 *	log_status: HTTP request status
 *	ben_sec: time for response (in seconds)
 *	ben_usec: microseconds part
 *
 *	Apache Stats:
 *	------------
 *	ben_ready: count of ready process
 *	ben_busy: count of busy process
 *
 *	Process stats:
 *	-------------
 *	ben_pzombie: count of zombie process (unuseful ?)
 *	ben_prunning: count of running process
 *	ben_pstopped: count of stopped process
 *	ben_psleeping: coutn of sleepin process
 *
 * 	The following percentages are given on a 1000 basis:
 *
 *	ben_avgload: average CPU load
 *	ben_memuse: percentage of memory used
 *	ben_swapuse: percentage of swap used
 *
 *	Fields added from version 1.2:
 *	-----------------------------
 *	fil_value: filename after URI translation
 *	ben_cliaddr: IP address of client
 *	ben_srvaddr: IP address of server
 *
 *	Fields added from version 1.5:
 *	-----------------------------
 * 	ben_srvport: local port (HTTP, HTTPS...)
 *
 */

/*
 * ----------------------------------------------------------------
 *
 * t_benchmark_alert: contains one row per generated alert
 *
 * ----------------------------------------------------------------
 */
IF EXISTS (SELECT * FROM sysobjects WHERE name = 't_benchmark_alert' AND type = 'U')
	DROP TABLE t_benchmark_alert
GO

CREATE TABLE t_benchmark_alert (
	log_date 	DATETIME,
	url_value	VARCHAR(250),
	arg_value	VARCHAR(250),
	fil_value	VARCHAR(250),
	ben_sec		INT,
	ben_usec	INT,
	ben_cliaddr	INT,
	ben_srvaddr	INT
	)

exec sp_bindefault BENCHMARK_DATE_0, "t_benchmark_alert.log_date"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_alert.url_value"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_alert.arg_value"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_alert.fil_value"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_alert.ben_sec"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_alert.ben_usec"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_alert.ben_cliaddr"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_alert.ben_srvaddr"

GO

/* 
 * Notes:
 * =====
 *
 *	Fields added from version 1.2:
 *	-----------------------------
 *	fil_value: filename after URI translation
 *	ben_cliaddr: IP address of client
 *	ben_srvaddr: IP address of server
 *
 */

/* 
 * ----------------------------------------------------------------
 *
 * t_benchmark_graph: contains the saved Reports
 *
 * ----------------------------------------------------------------
 */
IF EXISTS (SELECT * FROM sysobjects WHERE name = 't_benchmark_graph' AND type = 'U')
	DROP TABLE t_benchmark_graph
GO

CREATE TABLE t_benchmark_graph (
	gra_id		INT,
	gra_name	VARCHAR(64),
	gra_date	DATETIME,
	gra_note	TEXT,
	gra_blob	TEXT,
	gra_width	INT,
	gra_height	INT,
	CONSTRAINT	gra_pk PRIMARY KEY (gra_id)
)

exec sp_bindefault BENCHMARK_DATE_0, "t_benchmark_graph.gra_date"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_graph.gra_name"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_graph.gra_note"
exec sp_bindefault BENCHMARK_STRING_0, "t_benchmark_graph.gra_blob"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_graph.gra_width"
exec sp_bindefault BENCHMARK_INT_0, "t_benchmark_graph.gra_height"

GO

# Notes:
# =====
#
#	gra_blob: Reports are limited to 64Kb
#
/* EOF */
